@@ -4,8 +4,6 @@ use strict;
 use warnings;
 use base qw( Alien::Base::ModuleBuild );
 use File::Spec;
-use File::Path qw( mkpath );
-use File::Spec qw( copy );
 
 sub new
 {
@@ -141,7 +139,10 @@ sub alien_install
   else
   {
     _system $make, 'install', "PREFIX=$dir";
-    _system $cp, '-a', 'libbz2.so.1.0.6', 'libbz2.so.1.0', "$dir/lib";
+    eval {
+      _system $cp, '-a', 'libbz2.so.1.0.6', 'libbz2.so.1.0', "$dir/lib";
+      1;
+    } || _system $cp, '-p', 'libbz2.so.1.0.6', 'libbz2.so.1.0', "$dir/lib";
   }
 }
 
