@@ -7,7 +7,7 @@ use Text::ParseWords qw( shellwords );
 use File::Spec;
 
 # ABSTRACT: Build and make available libbz2
-our $VERSION = '0.09'; # VERSION
+our $VERSION = '0.10'; # VERSION
 
 
 sub _dir
@@ -41,7 +41,7 @@ sub import
   # which is undesirable.  Better to have a dll directory and
   # copy the dlls there during the install process
   $ENV{PATH} = $class->dist_dir . "\\bin;$ENV{PATH}" if $^O eq 'MSWin32';
-  $ENV{PATH} = $class->dist_dir . "/bin;$ENV{PATH}"  if $^O eq 'cygwin';
+  $ENV{PATH} = $class->dist_dir . "/bin:$ENV{PATH}"  if $^O eq 'cygwin';
   
   $class->SUPER::import(@_);
 }
@@ -60,7 +60,7 @@ Alien::bz2 - Build and make available libbz2
 
 =head1 VERSION
 
-version 0.09
+version 0.10
 
 =head1 SYNOPSIS
 
